@@ -137,8 +137,8 @@ class BstError(Exception):
 # or by the base :class:`.Plugin` element itself.
 #
 class PluginError(BstError):
-    def __init__(self, message, reason=None, temporary=False):
-        super().__init__(message, domain=ErrorDomain.PLUGIN, reason=reason, temporary=False)
+    def __init__(self, message, *, detail=None, reason=None, temporary=False):
+        super().__init__(message, domain=ErrorDomain.PLUGIN, detail=detail, reason=reason, temporary=False)
 
 
 # LoadErrorReason
@@ -219,6 +219,9 @@ class LoadErrorReason(Enum):
     # A recursive variable has been encountered
     RECURSIVE_VARIABLE = 22
 
+    # An attempt so set the value of a protected variable
+    PROTECTED_VARIABLE_REDEFINED = 23
+
 
 # LoadError
 #
@@ -308,3 +311,12 @@ class StreamError(BstError):
 class AppError(BstError):
     def __init__(self, message, detail=None, reason=None):
         super().__init__(message, detail=detail, domain=ErrorDomain.APP, reason=reason)
+
+
+# SkipJob
+#
+# Raised from a child process within a job when the job should be
+# considered skipped by the parent process.
+#
+class SkipJob(Exception):
+    pass
